@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-VERSION = '0.8.3' # (major.minor.sub-minor)
+VERSION = '0.8.4444' # (major.minor.sub-minor)
 
 # Minor version changes each time database schema changes 
 # See CHANGELOG.md for detailed change history
@@ -1637,6 +1637,8 @@ etc. of all habits, whereas the daily habits view only shows habits for the curr
                     'null_measure':'1', \
                     'priority':'2', \
                     'target':'1', \
+                    'deleted_date':None, \
+                    'paused_until_date':None, \
                     }
             win_title = _(WIN_TITLE_ADD_NEW_HABIT)
         else:
@@ -1717,7 +1719,7 @@ etc. of all habits, whereas the daily habits view only shows habits for the curr
 
         # Delete/undelete button
         delete_btn = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-        if self.db_date_is_past(self.editing_habit['deleted_date']):
+        if 'deleted_date' in self.editing_habit and self.db_date_is_past(self.editing_habit['deleted_date']):
             delete_btn.set_label(_('Undelete'))
         else:
             delete_btn.set_label(_('Delete'))
@@ -1726,7 +1728,7 @@ etc. of all habits, whereas the daily habits view only shows habits for the curr
 
         # Pause/unpause button
         pause_btn = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-        if self.db_date_is_future(habit['paused_until_date']):
+        if 'paused_until_date' in self.editing_habit and self.db_date_is_future(self.editing_habit['paused_until_date']):
             pause_btn.set_label(_('Unpause'))
         else:
             pause_btn.set_label(_('Pause'))
@@ -1788,10 +1790,10 @@ etc. of all habits, whereas the daily habits view only shows habits for the curr
 
 
     def get_edit_habit_status_label_text(self, habit):
-        if self.db_date_is_past(habit['deleted_date']):
+        if 'deleted_date' in habit and self.db_date_is_past(habit['deleted_date']):
             habit_info = _('Deleted')
             habit_info += ' ' + self.db_date_to_display_date(habit['deleted_date'])
-        elif self.db_date_is_future(habit['paused_until_date']):
+        elif 'paused_until_date' in habit and self.db_date_is_future(habit['paused_until_date']):
             habit_info = _('Paused until')
             habit_info += ' '
             if self.db_date_to_dt(habit['paused_until_date']) == self.get_today_dt():
